import { App } from "obsidian";
import { TextInputSuggest } from "./core";

export class FieldSuggest extends TextInputSuggest<string> {
	constructor(
		app: App,
		inputEl: HTMLInputElement,
		private readonly accepts?: string[]
	) {
		super(app, inputEl);
	}

	async getSuggestions(inputStr: string): Promise<string[]> {
		const typesContent = await this.app.vault.adapter.read(
			this.app.vault.configDir + "/types.json"
		);
		const types = JSON.parse(typesContent).types;

		return Object.entries(types)
			.filter(([field, type]) => {
				if (this.accepts && !this.accepts.includes(type as string)) {
					return false;
				}

				return field.toLowerCase().includes(inputStr.toLowerCase());
			})
			.map(([field, _]) => field);
	}

	renderSuggestion(field: string, el: HTMLElement): void {
		el.setText(field);
	}

	selectSuggestion(field: string): void {
		this.inputEl.value = field;
		this.inputEl.trigger("input");
		this.close();
	}
}
