import Rating from "@components/Rating.svelte";
import { Event, EventEmitter } from "@utils/event";
import { App } from "obsidian";
import { SvelteModal } from "./svelte-modal";

class SubmitEvent extends Event {
	constructor(public readonly rating: number) {
		super();
	}
}

interface RatingModalEventMap {
	submit: SubmitEvent;
}

export class RatingModal extends EventEmitter<
	RatingModalEventMap,
	typeof SvelteModal<typeof Rating>
>(SvelteModal) {
	constructor(app: App) {
		super(app, Rating, {
			props: {
				onSubmit: (rating: number) =>
					this.emit("submit", new SubmitEvent(rating)),
			},
		});
	}

	static createAndOpen(app: App): Promise<number> {
		return new Promise((resolve) => {
			const modal = new RatingModal(app);
			modal.once("submit", (event: SubmitEvent) => {
				modal.close();
				resolve(event.rating);
			});
			modal.open();
		});
	}
}
