import ReadingProgress from "@components/ReadingProgress.svelte";
import { Event, EventEmitter } from "@utils/event";
import { App } from "obsidian";
import { SvelteModal } from "./svelte-modal";

export class SubmitEvent extends Event {
	constructor(public readonly pageNumber: number) {
		super();
	}
}

interface ReadingProgressModalEventMap {
	submit: SubmitEvent;
}

export class ReadingProgressModal extends EventEmitter<
	ReadingProgressModalEventMap,
	typeof SvelteModal<typeof ReadingProgress>
>(SvelteModal) {
	constructor(app: App, pageLength: number) {
		super(app, ReadingProgress, {
			props: {
				pageLength,
				onSubmit: (pageNumber: number) => {
					this.emit("submit", new SubmitEvent(pageNumber));
				},
			},
		});
	}

	static createAndOpen(app: App, pageLength: number): Promise<number> {
		return new Promise((resolve) => {
			const modal = new ReadingProgressModal(app, pageLength);
			modal.once("submit", (event: SubmitEvent) => {
				modal.close();
				resolve(event.pageNumber);
			});
			modal.open();
		});
	}
}
